
<template>
  <view-grid
    ref="grid"
    :columns="columns"
    :detail="detail"
    :editFormFields="editFormFields"
    :editFormOptions="editFormOptions"
    :searchFormFields="searchFormFields"
    :searchFormOptions="searchFormOptions"
    :table="table"
    :extend="extend"
  ></view-grid>
</template>
    <script>
import extend from "@/extension/wmsPart/stockInfo.js";
import { ref, defineComponent } from "vue";
export default defineComponent({
  setup() {
    const table = ref({
      key: "id",
      footer: "Foots",
      cnName: "库存信息",
      name: "stockInfo",
      url: "/StockInfo/",
      sortName: "id"
    });
    const editFormFields = ref({
      deviceCode: "",
      deviceName: "",
      deviceType: "",
      deviceStatus: "",
      deviceIp: "",
      devicePort: "",
      devicePlcType: "",
      deviceRemark: ""
    });
    const editFormOptions = ref([
      [
        { field: "palletCode", title: "托盘编号", type: "string" },
        { field: "locationCode", title: "货位编号", type: "string" }
      ]
    ]);
    const searchFormFields = ref({
      palletCode: "",
      locationCode: ""
    });
    const searchFormOptions = ref([
      [
        { title: "托盘编号", field: "palletCode" },
        { title: "货位编号", field: "locationCode" }
      ]
    ]);
    const columns = ref([
      {
        field: "id",
        title: "Id",
        type: "int",
        width: 90,
        hidden: true,
        readonly: true,
        require: true,
        align: "left"
      },
      {
        field: "palletCode",
        title: "托盘编号",
        type: "string",
        width: 90,
        align: "left"
      },
      {
        field: "locationCode",
        title: "货位编号",
        type: "string",
        width: 150,
        align: "left"
      },
      // {
      //   field: "isFull",
      //   title: "是否满盘",
      //   type: "string",
      //   width: 150,
      //   align: "left",
      //   bind: { key: "yesno", data: [] },
      // },
      {
        field: "warehouseId",
        title: "仓库",
        type: "select",
        width: 100,
        align: "left",
        bind: { key: "warehouses", data: [] }
      },
      {
        field: "creater",
        title: "创建人",
        type: "string",
        width: 90,
        align: "left"
      },
      {
        field: "createDate",
        title: "创建时间",
        type: "datetime",
        width: 160,
        align: "left"
      },
      {
        field: "modifier",
        title: "修改人",
        type: "string",
        width: 100,
        align: "left",
        hidden: true
      },
      {
        field: "modifyDate",
        title: "修改时间",
        type: "datetime",
        width: 160,
        align: "left",
        hidden: true
      },
      {
        field: "remark",
        title: "备注",
        type: "string",
        width: 100,
        align: "left",
        hidden: true
      }
    ]);
    const detail = ref({
      cnName: "#detailCnName",
      table: "",
      columns: [],
      sortName: ""
    });
    return {
      table,
      extend,
      editFormFields,
      editFormOptions,
      searchFormFields,
      searchFormOptions,
      columns,
      detail
    };
  }
});
</script>
    